/** @file

hippodraw::HammerAito2 class implementation

Copyright (C) 2002-2005   The Board of Trustees of The Leland
Stanford Junior University.  All Rights Reserved.

$Id: HammerAito2.cxx,v 1.1 2007/03/14 23:28:29 xiefang Exp $

*/

#include "HammerAito2.h"
#include "UnaryTransform.h"

using namespace hippodraw;


HammerAito2::HammerAito2 ( UnaryTransform * z )
  : PeriodicBinaryTransform ( z, true, true, false, true,
			      -0.0, +360.0,
			      - 90.0, + 90.0 )
{
  m_name = "HammerAito2";
  const std::string projType("AIT");
  double crpix[] = {180, 0}, crval[] = {180,0}, cdelt[] = {1,1};
  initwcs (projType, crpix, crval, cdelt, 0, false);
}

HammerAito2::HammerAito2 ( const HammerAito2 & t )
  :  PeriodicBinaryTransform ( t )
{
  const std::string projType("AIT");
  double crpix[] = {180, 0}, crval[] = {180,0}, cdelt[] = {1,1};
  initwcs (projType, crpix, crval, cdelt, 0, false);
}

HammerAito2::~HammerAito2 ()
{
}

#ifdef CLONE_DEFECT
TransformBase * HammerAito2::clone () const
#else
HammerAito2    * HammerAito2::clone () const
#endif
{
  return new HammerAito2 ( *this );
}



/* virtual */
double HammerAito2::aspectRatio () const
{
  return 2.0;
}



